@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '3.48';
+$CPAN::Perl::Releases::VERSION = '3.92';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -211,10 +211,34 @@ our $data =
 "5.27.7" => { id => 'BINGOS' },
 "5.27.8" => { id => 'ABIGAIL' },
 "5.27.9" => { id => 'RENEEB' },
+"5.27.10" => { id => 'TODDR' },
+"5.24.4-RC1" => { id => 'SHAY' },
+"5.26.2-RC1" => { id => 'SHAY' },
+"5.24.4" => { id => 'SHAY' },
+"5.26.2" => { id => 'SHAY' },
+"5.27.11" => { id => 'XSAWYERX' },
+"5.28.0-RC1" => { id => 'XSAWYERX' },
+"5.28.0-RC2" => { id => 'XSAWYERX' },
+"5.28.0-RC3" => { id => 'XSAWYERX' },
+"5.28.0-RC4" => { id => 'XSAWYERX' },
+"5.28.0" => { id => 'XSAWYERX' },
+"5.29.0" => { id => 'XSAWYERX' },
+"5.29.1" => { id => 'SHAY' },
+"5.29.2" => { id => 'BINGOS' },
+"5.29.3" => { id => 'GENEHACK' },
+"5.29.4" => { id => 'ARC' },
+"5.29.5" => { id => 'ETHER' },
+"5.26.3" => { id => 'SHAY' },
+"5.28.1" => { id => 'SHAY' },
+"5.29.6" => { id => 'ABIGAIL' },
+"5.29.7" => { id => 'ABIGAIL' },
+"5.29.8" => { id => 'ATOOMIC' },
+"5.29.9" => { id => 'ZAKAME' },
 };
 
 sub perl_tarballs {
   my $vers = shift;
+  return unless defined $vers;
   $vers = shift if eval { $vers->isa(__PACKAGE__) };
   return unless exists $data->{ $vers };
   if ( exists $cache->{ $vers } ) {
@@ -278,7 +302,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 3.48
+version 3.92
 
 =head1 SYNOPSIS
 
@@ -337,15 +361,13 @@ Returns a sorted list of all PAUSE IDs of Perl pumpkins.
 
 L<http://www.cpan.org/src/5.0/>
 
-L<http://search.cpan.org/faq.html#Is_there_a_API?>
-
 =head1 AUTHOR
 
 Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Chris Williams.
+This software is copyright (c) 2019 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
